Module status

Module status 

This module contains a bitflags! generated struct for jack error codes, and some constants defining their default values

Structs

Status

Constants

BACKEND_ERROR
Backend error
CLIENT_ZOMBIE
Client zombified failure
FAILURE
overall operation failed
INIT_FAILURE
Unable to initialize client
INVALID_OPTION
The operation contained an invalid or unsupported option.
LOAD_FAILURE
Unable to load internal client
NAME_NOT_UNIQUE
The desired client name was not unique. With the JackUseExactName option this situation is fatal. Otherwise, the name was modified by appending a dash and a two-digit number in the range “-01” to “-99”. If the specified client name plus these extra characters would be too long, the open fails instead.
NO_SUCH_CLIENT
Requested client does not exist.
SERVER_ERROR
Communication error with the JACK server.
SERVER_FAILED
Unable to connect to the JACK server.
SERVER_STARTED
The JACK server was started as a result of this operation. Otherwise, it was running already. In either case the caller is now connected to jackd, so there is no race condition. When the server shuts down, the client will find out.
SHM_FAILURE
Unable to access shared memory
VERSION_ERROR
Client’s protocol version does not match