This module contains a bitflags! generated struct for jack error codes, and some constants defining their default values
Structs
Constants
- BACKEND_
ERROR - Backend error
- CLIENT_
ZOMBIE - Client zombified failure
- FAILURE
- overall operation failed
- INIT_
FAILURE - Unable to initialize client
- INVALID_
OPTION - The operation contained an invalid or unsupported option.
- LOAD_
FAILURE - Unable to load internal client
- NAME_
NOT_ UNIQUE - The desired client name was not unique. With the JackUseExactName option this situation is fatal. Otherwise, the name was modified by appending a dash and a two-digit number in the range “-01” to “-99”. If the specified client name plus these extra characters would be too long, the open fails instead.
- NO_
SUCH_ CLIENT - Requested client does not exist.
- SERVER_
ERROR - Communication error with the JACK server.
- SERVER_
FAILED - Unable to connect to the JACK server.
- SERVER_
STARTED - The JACK server was started as a result of this operation. Otherwise, it was running already. In either case the caller is now connected to jackd, so there is no race condition. When the server shuts down, the client will find out.
- SHM_
FAILURE - Unable to access shared memory
- VERSION_
ERROR - Client’s protocol version does not match